@@ -149,20 +149,20 @@ def get_from_pdg_extended(
         return lambda x: mapping[x.strip()]
 
     # Convert each column from text to appropriate data type
-    PDG_converters = dict(
-        Charge=unmap(Charge_mapping),
-        G=unmap(Parity_mapping),
-        P=unmap(Parity_mapping),
-        C=unmap(Parity_mapping),
-        Anti=unmap(Inv_mapping),
-        Rank=lambda x: int(x.strip()) if x.strip() else 0,
-        ID=lambda x: int(x.strip()) if x.strip() else -1,
-        Status=unmap(Status_mapping),
-        Name=lambda x: x.strip(),
-        I=lambda x: x.strip(),  # noqa: E741
-        J=lambda x: x.strip(),
-        Quarks=lambda x: x.strip(),
-    )
+    PDG_converters = {
+        "Charge": unmap(Charge_mapping),
+        "G": unmap(Parity_mapping),
+        "P": unmap(Parity_mapping),
+        "C": unmap(Parity_mapping),
+        "Anti": unmap(Inv_mapping),
+        "Rank": lambda x: int(x.strip()) if x.strip() else 0,
+        "ID": lambda x: int(x.strip()) if x.strip() else -1,
+        "Status": unmap(Status_mapping),
+        "Name": lambda x: x.strip(),
+        "I": lambda x: x.strip(),
+        "J": lambda x: x.strip(),
+        "Quarks": lambda x: x.strip(),
+    }
 
     with filter_file(filename) as file_object:
         # Read in the table, apply the converters, add names, ignore comments
@@ -281,7 +281,6 @@ def get_from_pdg_mcd(filename: StringOrIO) -> pd.DataFrame:
     # in the particle names, as well!
 
     with filter_file(filename) as file_object:
-
         nar = pd.read_fwf(
             file_object,
             colspecs=(
@@ -321,7 +320,7 @@ def get_from_pdg_mcd(filename: StringOrIO) -> pd.DataFrame:
             | nar.duplicated(subset=["ID4"], keep=False) & nar["ID4"].notna()
         )
         if nar[duplicated_ids].shape[0] > 0:
-            print("DUPLICATES:\n", nar[duplicated_ids])
+            print("DUPLICATES:\n", nar[duplicated_ids])  # noqa: T201
         assert (
             nar[duplicated_ids].shape[0] == 0
         ), f"Duplicate entries found in {filename} !"
@@ -371,14 +370,14 @@ def update_from_mcd(
 
 
 def produce_files(
-    particle2008: str | Path,  # pylint: disable=unused-argument
+    particle2008: str | Path,  # noqa: ARG001
     particle2022: str | Path,
     version: str,
     year: str,
 ) -> None:
     "This produces listed output files from all input files."
 
-    with data.basepath.joinpath("mass_width_2008.fwf").open() as fwf_f:
+    with data.basepath.joinpath("mass_width_2008.fwf").open() as fwf_f:  # noqa: SIM117
         with data.basepath.joinpath("pdgid_to_latexname.csv").open() as csv_f:
             full_table = get_from_pdg_extended(fwf_f, [csv_f])
 
@@ -397,9 +396,10 @@ def produce_files(
     with data.basepath.joinpath("mass_width_" + year + ".mcd").open() as mcd_f:
         ext_table = get_from_pdg_mcd(mcd_f)
 
-    with data.basepath.joinpath("mass_width_2008_ext.fwf").open() as fwf_f:
-        with data.basepath.joinpath("pdgid_to_latexname.csv").open() as csv_f:
-            addons = get_from_pdg_extended(fwf_f, [csv_f])
+    with data.basepath.joinpath(
+        "mass_width_2008_ext.fwf"
+    ).open() as fwf_f, data.basepath.joinpath("pdgid_to_latexname.csv").open() as csv_f:
+        addons = get_from_pdg_extended(fwf_f, [csv_f])
 
     # Only keep rows present in the .mcd file specified by year
     full_table = full_table[
