@@ -15,6 +15,7 @@ from typing import Any, Callable, Iterable, Iterator, Sequence, SupportsInt, Typ
 
 # External dependencies
 import attr
+from deprecated import deprecated
 from hepunits.constants import c_light
 
 from .. import data
@@ -206,7 +207,7 @@ class Particle:
     latex_name: str = attr.ib("Unknown")
 
     def __repr__(self) -> str:
-        return f'<{self.__class__.__name__}: name="{self}", pdgid={int(self.pdgid)}, mass={self._str_mass()}>'  # noqa: B907
+        return f'<{self.__class__.__name__}: name="{self}", pdgid={int(self.pdgid)}, mass={self._str_mass()}>'
 
     # Ordered loaded table of entries
     _table: list[Particle] | None = None
@@ -347,14 +348,14 @@ class Particle:
 
         >>> query_as_list = Particle.to_list(filter_fn=lambda p: p.pdgid.is_lepton and p.charge!=0, exclusive_fields=['pdgid', 'name', 'mass', 'charge'], particle=False)
         >>> print(tabulate(query_as_list, headers='firstrow', tablefmt="rst", floatfmt=".12g", numalign="decimal"))
-        =======  ======  ===============  ========
-          pdgid  name               mass    charge
-        =======  ======  ===============  ========
-            -11  e+         0.5109989461         1
-            -13  mu+      105.6583745            1
-            -15  tau+    1776.86                 1
-            -17  tau'+                           1
-        =======  ======  ===============  ========
+        =======  ======  =============  ========
+          pdgid  name             mass    charge
+        =======  ======  =============  ========
+            -11  e+         0.51099895         1
+            -13  mu+      105.6583755          1
+            -15  tau+    1776.86               1
+            -17  tau'+                         1
+        =======  ======  =============  ========
 
         >>> query_as_list = Particle.to_list(filter_fn=lambda p: p.pdgid.is_lepton, pdg_name='tau', exclusive_fields=['pdgid', 'name', 'mass', 'charge'])
         >>> print(tabulate(query_as_list, headers='firstrow'))
@@ -546,8 +547,8 @@ class Particle:
         if filename is None:
             with data.basepath.joinpath("particle2022.csv").open() as fa:
                 cls.load_table(fa, append=append, _name="particle2022.csv")
-            with data.basepath.joinpath("nuclei2020.csv").open() as fb:
-                cls.load_table(fb, append=True, _name="nuclei2020.csv")
+            with data.basepath.joinpath("nuclei2022.csv").open() as fb:
+                cls.load_table(fb, append=True, _name="nuclei2022.csv")
             return
         if isinstance(filename, HasRead):
             tmp_name = _name or filename.name
@@ -559,7 +560,7 @@ class Particle:
         else:
             cls._table_names.append(str(filename))
             assert not isinstance(filename, Traversable)
-            open_file = open(filename, encoding="utf_8")
+            open_file = open(filename, encoding="utf_8")  # noqa: SIM115
 
         with open_file as f:
             r = csv.DictReader(line for line in f if not line.startswith("#"))
@@ -718,9 +719,9 @@ class Particle:
 
         J = int(self.J)
         if J in {0, 1, 2}:
-            if self.P == Parity.p:
+            if Parity.p == self.P:
                 return (SpinType.Scalar, SpinType.Axial, SpinType.Tensor)[J]
-            if self.P == Parity.m:
+            if Parity.m == self.P:
                 spin_types = (
                     SpinType.PseudoScalar,
                     SpinType.Vector,
@@ -1191,7 +1192,6 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         particle: bool | None = None,
         **search_terms: Any,
     ) -> list[Self]:
-
         """
         Search for a particle, returning a list of candidates.
 
@@ -1213,15 +1213,15 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
 
            >>> # Returns proton and antiproton only
            >>> Particle.findall(pdg_name='p')    # doctest: +NORMALIZE_WHITESPACE
-           [<Particle: name="p", pdgid=2212, mass=938.272081 ± 0.000006 MeV>,
-            <Particle: name="p~", pdgid=-2212, mass=938.272081 ± 0.000006 MeV>,
-            <Particle: name="p", pdgid=1000010010, mass=938.272081 ± 0.000006 MeV>,
-            <Particle: name="p~", pdgid=-1000010010, mass=938.272081 ± 0.000006 MeV>]
+           [<Particle: name="p", pdgid=2212, mass=938.2720882 ± 0.0000003 MeV>,
+            <Particle: name="p~", pdgid=-2212, mass=938.2720882 ± 0.0000003 MeV>,
+            <Particle: name="p", pdgid=1000010010, mass=938.2720882 ± 0.0000003 MeV>,
+            <Particle: name="p~", pdgid=-1000010010, mass=938.2720882 ± 0.0000003 MeV>]
 
            >>> # Returns proton only
            >>> Particle.findall(pdg_name='p', particle=True)    # doctest: +NORMALIZE_WHITESPACE
-           [<Particle: name="p", pdgid=2212, mass=938.272081 ± 0.000006 MeV>,
-           <Particle: name="p", pdgid=1000010010, mass=938.272081 ± 0.000006 MeV>]
+           [<Particle: name="p", pdgid=2212, mass=938.2720882 ± 0.0000003 MeV>,
+           <Particle: name="p", pdgid=1000010010, mass=938.2720882 ± 0.0000003 MeV>]
 
         Versatile searches require a (lambda) function as argument:
 
@@ -1239,6 +1239,10 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         )
 
     @classmethod
+    @deprecated(
+        version="0.22",
+        reason="This method is deprecated and will be removed from version 0.23.0. Use finditer or findall instead.",
+    )
     def from_string(cls: type[Self], name: str) -> Self:
         "Get a particle from a PDG style name - returns the best match."
         matches = cls.from_string_list(name)
@@ -1247,6 +1251,10 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
         raise ParticleNotFound(f"{name} not found in particle table")
 
     @classmethod
+    @deprecated(
+        version="0.22",
+        reason="This method is deprecated and will be removed from version 0.23.0. Use finditer or findall instead.",
+    )
     def from_string_list(cls: type[Self], name: str) -> list[Self]:
         "Get a list of particles from a PDG style name."
 
@@ -1283,7 +1291,6 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
 
     @classmethod
     def _from_group_dict_list(cls: type[Self], mat: dict[str, Any]) -> list[Self]:
-
         kw: dict[str, Any] = {
             "particle": False
             if mat["bar"] is not None
@@ -1325,6 +1332,6 @@ C (charge parity) = {C:<6}  I (isospin)       = {self.I!s:<7}  G (G-parity)
             vals = [val for val in vals if mat["mass"] in val.latex_name]
 
         if len(vals) > 1:
-            vals = sorted(vals)
+            return sorted(vals)
 
         return vals
