@@ -1,4 +1,4 @@
-# Copyright (c) 2018-2022, Eduardo Rodrigues and Henry Schreiner.
+# Copyright (c) 2018-2023, Eduardo Rodrigues and Henry Schreiner.
 #
 # Distributed under the 3-clause BSD license, see accompanying file LICENSE
 # or https://github.com/scikit-hep/particle for details.
@@ -43,8 +43,11 @@ class PDGIDsEnum(IntEnum):
     # Quarkonia
     jpsi = 443
     psi_2S = 100443
+    psi_3770 = 30443
     Upsilon_1S = 553
     Upsilon_4S = 300553
+    Upsilon_3_2D = 100557
+    h_b_3P = 210553
     # Light hadrons
     Pi0 = 111
     PiPlus = 211
@@ -55,13 +58,23 @@ class PDGIDsEnum(IntEnum):
     KS = 310
     KMinus = -321
     rho_770_minus = -213
+    rho_10219_plus = 10219  # unknown particle added for testing purposes
     phi = 333
     omega = 223
     K1_1270_0 = 10313
     K1_1400_0 = 20313
+    K2_1770_minus = -10325
+    K2_1820_0_bar = -20315
+    K3_10317_0 = 10317  # unknown particle added for testing purposes
+    K3_20317_plus = 20317  # unknown particle added for testing purposes
+    K3_30317_0 = 30317  # unknown particle added for testing purposes
+    K4_20219_minus = -20219  # unknown particle added for testing purposes
+    K4_30329_plus = 30329  # unknown particle added for testing purposes
     rho_1700_0 = 30113
     a2_1320_minus = -215
     omega_3_1670 = 227
+    f_2_30225 = 30225  # unknown particle added for testing purposes
+    f_4_2050 = 229
     f_4_2300 = 9010229  # example of a not-well-known meson
     Proton = 2212
     AntiNeutron = -2112
@@ -72,6 +85,9 @@ class PDGIDsEnum(IntEnum):
     Xi0 = 3322
     AntiXiMinus = -3312
     OmegaMinus = 3334
+    N1650Plus = 32212
+    N1900BarMinus = -42124
+    Lambda1810 = 53122
     # Charm hadrons
     D0 = 421
     DPlus = 411
@@ -97,6 +113,7 @@ class PDGIDsEnum(IntEnum):
     STildeL = 1000003
     CTildeR = 2000004
     # R-hadrons
+    R0_1000017 = 1000017
     RPlus_TTildeDbar = 1000612
     R0_GTildeG = 1000993
     RPlusPlus_GTildeUUU = 1092224
@@ -109,6 +126,8 @@ class PDGIDsEnum(IntEnum):
     # Di-quarks
     DD1 = 1103
     SD0 = 3101
+    # Hidden Valley particles
+    HV_gv = 4900021
     # Nuclei
     HydrogenNucleus = 1000010010
     Carbon12 = 1000060120
@@ -124,6 +143,13 @@ class PDGIDsEnum(IntEnum):
     AntiElectronStar = -4000011
     # Generator specific pseudoparticles or concepts
     AntiCHadron = -84
+    GenSpecific910 = 910
+    GenSpecific999 = 999
+    GenSpecific1910 = 1910
+    GenSpecific2910 = 2910
+    GenSpecific3910 = 3910
+    OpticalPhoton = 20022
+    Geantino = 480000000
     # Invalid ID
     Invalid1 = 0  # illegal ID
     Invalid2 = 99999999  # general form is a 7-digit number
